@@ -1,11 +1,15 @@
 from os.path import join, abspath, basename
 import re
-from csmash import ConfigSmasher
 
-version_info = (0, 0, 3)
+version_info = (0, 0, 4)
 __version__ = '.'.join(map(str, version_info))
 version = __version__
 
+try:
+    from csmash import ConfigSmasher
+except ImportError:
+    print 'COULD NOT IMPORT csmash, will not work'
+
 class SelectiveConfigSmasher(ConfigSmasher):
     def __init__(self, to_smash=None, pattern=None):
         ConfigSmasher.__init__(self, to_smash)
